package VMOMI::GuestPosixFileAttributes;
use parent 'VMOMI::GuestFileAttributes';

use strict;
use warnings;

our @class_ancestors = ( 
    'GuestFileAttributes',
    'DynamicData',
);

our @class_members = ( 
    ['ownerId', undef, 0, 1],
    ['groupId', undef, 0, 1],
    ['permissions', undef, 0, 1],
);

sub get_class_ancestors {
    return @class_ancestors;
}

sub get_class_members {
    my $class = shift;
    my @super_members = $class->SUPER::get_class_members();
    return (@super_members, @class_members);
}

1;
